//*
//# Расширения (Extensions)
//
//Расширения представляют собой отдельные сервисы предоставляющие дополнительные возможности для пользователей. Сервис
//может предоставлять несколько расширений одновременно.
//
//Для координации взаимодействия используется сервис менеджер расширений (Extension Manager). Для предоставления своих функций в систему сервис должен
//зарегистрироваться на контроллере.
//

// Code generated by protoc-gen-go-grpc. DO NOT EDIT.
// versions:
// - protoc-gen-go-grpc v1.3.0
// - protoc             v3.21.12
// source: extensions/extension.proto

package extensions

import (
	context "context"
	grpc "google.golang.org/grpc"
	codes "google.golang.org/grpc/codes"
	status "google.golang.org/grpc/status"
)

// This is a compile-time assertion to ensure that this generated file
// is compatible with the grpc package it is being compiled against.
// Requires gRPC-Go v1.32.0 or later.
const _ = grpc.SupportPackageIsVersion7

const (
	Extension_Install_FullMethodName   = "/extensions.Extension/Install"
	Extension_Check_FullMethodName     = "/extensions.Extension/Check"
	Extension_Update_FullMethodName    = "/extensions.Extension/Update"
	Extension_Uninstall_FullMethodName = "/extensions.Extension/Uninstall"
	Extension_Action_FullMethodName    = "/extensions.Extension/Action"
)

// ExtensionClient is the client API for Extension service.
//
// For semantics around ctx use and closing/ending streaming RPCs, please refer to https://pkg.go.dev/google.golang.org/grpc/?tab=doc#ClientConn.NewStream.
type ExtensionClient interface {
	// Для установки расширения выполняется запрос к сервису с указанием расширений которые должны быть установлены. Если
	// расширение уже установлено процесс возвращает ошибку.
	Install(ctx context.Context, in *InstallRequest, opts ...grpc.CallOption) (*InstallResponse, error)
	// Можно запросить проверку статуса установки для расширения. При этом расширение проверяет наличие необходимых данных в
	// пространстве или наличие новой версии расширения и сообщает об этом. Никаких действий с данными пространства не
	// производится.
	Check(ctx context.Context, in *CheckRequest, opts ...grpc.CallOption) (*CheckResponse, error)
	// Сервис выполняет необходимые действия с данными и миграции для соответствия нужной версии расширения.
	// Если расширение не установлено процесс обновления возвращает ошибку.
	Update(ctx context.Context, in *UpdateRequest, opts ...grpc.CallOption) (*UpdateResponse, error)
	// Удаление расширения из пространства.
	Uninstall(ctx context.Context, in *UninstallRequest, opts ...grpc.CallOption) (*UninstallResponse, error)
	// Пользовательские Действия (Actions)
	//
	// Пользовательские действия позволяют расширить функционал пользовательского интерфейса путем
	// добавления в интерфейс элементов взаимодействуя с которыми пользователь может вызывать реакцию на
	// сервере или переход в интерфейсе.
	//
	// Пользовательские действия добавляются при установке расширений в системную коллекции `System/Actions`.
	// Коллекция создается автоматически менеджером расширений. При установке так же отображается меню `Действия`
	// доступное для всех пользователей.
	//
	// Примеры пользовательских действий:
	//   - "Собрать сайт" - добавляется Perxis.Web для сборки сайта, доступна пользователю через меню,
	//     параметры space_id, env_id. При вызове выполняется запрос на сервер ProcessAction.
	//   - "Посмотреть задачи" - добавляется Tasks для перехода на коллекцию задач. Отображается в меню,
	//     параметры space_id, env_id.
	//
	// Приложения так же могут использовать действия для вызова обработки в других приложениях при
	// необходимости.
	Action(ctx context.Context, in *ActionRequest, opts ...grpc.CallOption) (*ActionResponse, error)
}

type extensionClient struct {
	cc grpc.ClientConnInterface
}

func NewExtensionClient(cc grpc.ClientConnInterface) ExtensionClient {
	return &extensionClient{cc}
}

func (c *extensionClient) Install(ctx context.Context, in *InstallRequest, opts ...grpc.CallOption) (*InstallResponse, error) {
	out := new(InstallResponse)
	err := c.cc.Invoke(ctx, Extension_Install_FullMethodName, in, out, opts...)
	if err != nil {
		return nil, err
	}
	return out, nil
}

func (c *extensionClient) Check(ctx context.Context, in *CheckRequest, opts ...grpc.CallOption) (*CheckResponse, error) {
	out := new(CheckResponse)
	err := c.cc.Invoke(ctx, Extension_Check_FullMethodName, in, out, opts...)
	if err != nil {
		return nil, err
	}
	return out, nil
}

func (c *extensionClient) Update(ctx context.Context, in *UpdateRequest, opts ...grpc.CallOption) (*UpdateResponse, error) {
	out := new(UpdateResponse)
	err := c.cc.Invoke(ctx, Extension_Update_FullMethodName, in, out, opts...)
	if err != nil {
		return nil, err
	}
	return out, nil
}

func (c *extensionClient) Uninstall(ctx context.Context, in *UninstallRequest, opts ...grpc.CallOption) (*UninstallResponse, error) {
	out := new(UninstallResponse)
	err := c.cc.Invoke(ctx, Extension_Uninstall_FullMethodName, in, out, opts...)
	if err != nil {
		return nil, err
	}
	return out, nil
}

func (c *extensionClient) Action(ctx context.Context, in *ActionRequest, opts ...grpc.CallOption) (*ActionResponse, error) {
	out := new(ActionResponse)
	err := c.cc.Invoke(ctx, Extension_Action_FullMethodName, in, out, opts...)
	if err != nil {
		return nil, err
	}
	return out, nil
}

// ExtensionServer is the server API for Extension service.
// All implementations must embed UnimplementedExtensionServer
// for forward compatibility
type ExtensionServer interface {
	// Для установки расширения выполняется запрос к сервису с указанием расширений которые должны быть установлены. Если
	// расширение уже установлено процесс возвращает ошибку.
	Install(context.Context, *InstallRequest) (*InstallResponse, error)
	// Можно запросить проверку статуса установки для расширения. При этом расширение проверяет наличие необходимых данных в
	// пространстве или наличие новой версии расширения и сообщает об этом. Никаких действий с данными пространства не
	// производится.
	Check(context.Context, *CheckRequest) (*CheckResponse, error)
	// Сервис выполняет необходимые действия с данными и миграции для соответствия нужной версии расширения.
	// Если расширение не установлено процесс обновления возвращает ошибку.
	Update(context.Context, *UpdateRequest) (*UpdateResponse, error)
	// Удаление расширения из пространства.
	Uninstall(context.Context, *UninstallRequest) (*UninstallResponse, error)
	// Пользовательские Действия (Actions)
	//
	// Пользовательские действия позволяют расширить функционал пользовательского интерфейса путем
	// добавления в интерфейс элементов взаимодействуя с которыми пользователь может вызывать реакцию на
	// сервере или переход в интерфейсе.
	//
	// Пользовательские действия добавляются при установке расширений в системную коллекции `System/Actions`.
	// Коллекция создается автоматически менеджером расширений. При установке так же отображается меню `Действия`
	// доступное для всех пользователей.
	//
	// Примеры пользовательских действий:
	//   - "Собрать сайт" - добавляется Perxis.Web для сборки сайта, доступна пользователю через меню,
	//     параметры space_id, env_id. При вызове выполняется запрос на сервер ProcessAction.
	//   - "Посмотреть задачи" - добавляется Tasks для перехода на коллекцию задач. Отображается в меню,
	//     параметры space_id, env_id.
	//
	// Приложения так же могут использовать действия для вызова обработки в других приложениях при
	// необходимости.
	Action(context.Context, *ActionRequest) (*ActionResponse, error)
	mustEmbedUnimplementedExtensionServer()
}

// UnimplementedExtensionServer must be embedded to have forward compatible implementations.
type UnimplementedExtensionServer struct {
}

func (UnimplementedExtensionServer) Install(context.Context, *InstallRequest) (*InstallResponse, error) {
	return nil, status.Errorf(codes.Unimplemented, "method Install not implemented")
}
func (UnimplementedExtensionServer) Check(context.Context, *CheckRequest) (*CheckResponse, error) {
	return nil, status.Errorf(codes.Unimplemented, "method Check not implemented")
}
func (UnimplementedExtensionServer) Update(context.Context, *UpdateRequest) (*UpdateResponse, error) {
	return nil, status.Errorf(codes.Unimplemented, "method Update not implemented")
}
func (UnimplementedExtensionServer) Uninstall(context.Context, *UninstallRequest) (*UninstallResponse, error) {
	return nil, status.Errorf(codes.Unimplemented, "method Uninstall not implemented")
}
func (UnimplementedExtensionServer) Action(context.Context, *ActionRequest) (*ActionResponse, error) {
	return nil, status.Errorf(codes.Unimplemented, "method Action not implemented")
}
func (UnimplementedExtensionServer) mustEmbedUnimplementedExtensionServer() {}

// UnsafeExtensionServer may be embedded to opt out of forward compatibility for this service.
// Use of this interface is not recommended, as added methods to ExtensionServer will
// result in compilation errors.
type UnsafeExtensionServer interface {
	mustEmbedUnimplementedExtensionServer()
}

func RegisterExtensionServer(s grpc.ServiceRegistrar, srv ExtensionServer) {
	s.RegisterService(&Extension_ServiceDesc, srv)
}

func _Extension_Install_Handler(srv interface{}, ctx context.Context, dec func(interface{}) error, interceptor grpc.UnaryServerInterceptor) (interface{}, error) {
	in := new(InstallRequest)
	if err := dec(in); err != nil {
		return nil, err
	}
	if interceptor == nil {
		return srv.(ExtensionServer).Install(ctx, in)
	}
	info := &grpc.UnaryServerInfo{
		Server:     srv,
		FullMethod: Extension_Install_FullMethodName,
	}
	handler := func(ctx context.Context, req interface{}) (interface{}, error) {
		return srv.(ExtensionServer).Install(ctx, req.(*InstallRequest))
	}
	return interceptor(ctx, in, info, handler)
}

func _Extension_Check_Handler(srv interface{}, ctx context.Context, dec func(interface{}) error, interceptor grpc.UnaryServerInterceptor) (interface{}, error) {
	in := new(CheckRequest)
	if err := dec(in); err != nil {
		return nil, err
	}
	if interceptor == nil {
		return srv.(ExtensionServer).Check(ctx, in)
	}
	info := &grpc.UnaryServerInfo{
		Server:     srv,
		FullMethod: Extension_Check_FullMethodName,
	}
	handler := func(ctx context.Context, req interface{}) (interface{}, error) {
		return srv.(ExtensionServer).Check(ctx, req.(*CheckRequest))
	}
	return interceptor(ctx, in, info, handler)
}

func _Extension_Update_Handler(srv interface{}, ctx context.Context, dec func(interface{}) error, interceptor grpc.UnaryServerInterceptor) (interface{}, error) {
	in := new(UpdateRequest)
	if err := dec(in); err != nil {
		return nil, err
	}
	if interceptor == nil {
		return srv.(ExtensionServer).Update(ctx, in)
	}
	info := &grpc.UnaryServerInfo{
		Server:     srv,
		FullMethod: Extension_Update_FullMethodName,
	}
	handler := func(ctx context.Context, req interface{}) (interface{}, error) {
		return srv.(ExtensionServer).Update(ctx, req.(*UpdateRequest))
	}
	return interceptor(ctx, in, info, handler)
}

func _Extension_Uninstall_Handler(srv interface{}, ctx context.Context, dec func(interface{}) error, interceptor grpc.UnaryServerInterceptor) (interface{}, error) {
	in := new(UninstallRequest)
	if err := dec(in); err != nil {
		return nil, err
	}
	if interceptor == nil {
		return srv.(ExtensionServer).Uninstall(ctx, in)
	}
	info := &grpc.UnaryServerInfo{
		Server:     srv,
		FullMethod: Extension_Uninstall_FullMethodName,
	}
	handler := func(ctx context.Context, req interface{}) (interface{}, error) {
		return srv.(ExtensionServer).Uninstall(ctx, req.(*UninstallRequest))
	}
	return interceptor(ctx, in, info, handler)
}

func _Extension_Action_Handler(srv interface{}, ctx context.Context, dec func(interface{}) error, interceptor grpc.UnaryServerInterceptor) (interface{}, error) {
	in := new(ActionRequest)
	if err := dec(in); err != nil {
		return nil, err
	}
	if interceptor == nil {
		return srv.(ExtensionServer).Action(ctx, in)
	}
	info := &grpc.UnaryServerInfo{
		Server:     srv,
		FullMethod: Extension_Action_FullMethodName,
	}
	handler := func(ctx context.Context, req interface{}) (interface{}, error) {
		return srv.(ExtensionServer).Action(ctx, req.(*ActionRequest))
	}
	return interceptor(ctx, in, info, handler)
}

// Extension_ServiceDesc is the grpc.ServiceDesc for Extension service.
// It's only intended for direct use with grpc.RegisterService,
// and not to be introspected or modified (even as a copy)
var Extension_ServiceDesc = grpc.ServiceDesc{
	ServiceName: "extensions.Extension",
	HandlerType: (*ExtensionServer)(nil),
	Methods: []grpc.MethodDesc{
		{
			MethodName: "Install",
			Handler:    _Extension_Install_Handler,
		},
		{
			MethodName: "Check",
			Handler:    _Extension_Check_Handler,
		},
		{
			MethodName: "Update",
			Handler:    _Extension_Update_Handler,
		},
		{
			MethodName: "Uninstall",
			Handler:    _Extension_Uninstall_Handler,
		},
		{
			MethodName: "Action",
			Handler:    _Extension_Action_Handler,
		},
	},
	Streams:  []grpc.StreamDesc{},
	Metadata: "extensions/extension.proto",
}
